@@ -1,5 +1,5 @@
 ".onAttach"=function(libname, pkgname) {
-    if (interactive()) {
+    if (interactive() && exists('packageVersion') && exists('packageStartupMessage')) {
         packageStartupMessage('Welcome to multitable ',as.character(packageVersion("multitable")),'\nType vignette("multitable") or help("multitable") to get started')
     }
     invisible(NULL)
